@@ -14,7 +14,7 @@ static AEffectDispatcherProc s_plug2host;
 
 static
 t_fstPtrInt host2plugin (AEffect* effect, int opcode, int index, t_fstPtrInt ivalue, void*ptr, float fvalue) {
-  //printf("host2plugin:%d\n", opcode); fflush(stdout);
+  //printf("%s(%d, %d, %lld, %p, %f)\n",  __FUNCTION__, opcode, index, ivalue, ptr, fvalue); fflush(stdout);
   switch(opcode) {
   case effGetVendorString:
     printf("getVendorString\n");
@@ -27,10 +27,19 @@ t_fstPtrInt host2plugin (AEffect* effect, int opcode, int index, t_fstPtrInt iva
   case 26:
     printf("OPCODE26: %d\n", index);
     return (index<5);
+  case 42:
+    printf("OPCODE42: %d, %lld, %p, %f\n", index, ivalue, ptr, fvalue);fflush(stdout);
+    break;
+  case effVendorSpecific:
+    printf("effVendorSpecific(0x%X, 0x%X)\n", index, ivalue);
+    print_hex(ptr, 256);
+    break;
   case 56:
+#if 0
     printf("OPCODE56\n");
     print_hex(ptr, 256);
     return dispatch_effect("???", s_host2plugin[effect], effect, opcode, index, ivalue, 0, fvalue);
+#endif
     break;
   case 62:
     return 0;
@@ -69,6 +78,7 @@ t_fstPtrInt host2plugin (AEffect* effect, int opcode, int index, t_fstPtrInt iva
 #endif
   switch(opcode) {
   default: break;
+  case 56: case 53:
   case effGetChunk: case effSetChunk:
   case effVendorSpecific:
     doPrint = false;
@@ -91,16 +101,24 @@ t_fstPtrInt host2plugin (AEffect* effect, int opcode, int index, t_fstPtrInt iva
   }
   return result;
 }
+static
+t_fstPtrInt host2plugin_wrapper (AEffect* effect, int opcode, int index, t_fstPtrInt ivalue, void*ptr, float fvalue)
+{
+  t_fstPtrInt result;
+  fflush(stdout);
+  result = host2plugin(effect, opcode, index, ivalue, ptr, fvalue);
+  fflush(stdout);
 
+  return result;
+}
 static
 t_fstPtrInt plugin2host (AEffect* effect, int opcode, int index, t_fstPtrInt ivalue, void*ptr, float fvalue) {
-  //printf("plugin2host:%d\n", opcode); fflush(stdout);
+  //printf("%s:%d\n", __FUNCTION__, opcode); fflush(stdout);
   AEffectDispatcherProc p2h = s_plugin2host[effect];
-
   if(!p2h)p2h = s_plug2host;
   if(effect && !s_host2plugin[effect]) {
     s_host2plugin[effect] = effect->dispatcher;
-    effect->dispatcher = host2plugin;
+    effect->dispatcher = host2plugin_wrapper;
   }
   const char*pluginname = 0;
   if(effect)
@@ -112,23 +130,42 @@ t_fstPtrInt plugin2host (AEffect* effect, int opcode, int index, t_fstPtrInt iva
 #endif
   switch(opcode) {
   default: break;
+  case 14:
+    printf("hostCODE14\n");
+    //return 1;
+    break;
+  case 42:
+    printf("hostCODE42\n");
+    //return 0;
+    break;
+  case audioMasterGetCurrentProcessLevel:
   case audioMasterGetTime:
     doPrint = false;
     break;
+  case (int)0xDEADBEEF:
+    printf("0xDEADBEEF\n");
   }
   t_fstPtrInt result = -1;
+
+  fflush(stdout);
   if(doPrint) {
     if(0xDEADBEEF ==opcode) {
-      if (0xDEADF00D == index) {
-        printf("\t0xDEADFEED/0xDEADF00D '%s'\n", ptr);
-      } else
-        printf("\t0x%X/0x%X\n", opcode, index);
+      unsigned int uindex = (unsigned int) index;
+      switch(uindex) {
+      case 0xDEADF00D:
+        printf("\t0x%X/0x%X '%s' ->\n", opcode, index, ptr);
+        break;
+      default:
+        printf("\t0x%X/0x%X ->\n", opcode, index);
+        break;
+      }
     }
 
     result = dispatch_host(pluginname, p2h, effect, opcode, index, ivalue, ptr, fvalue);
   } else {
     result = p2h(effect, opcode, index, ivalue, ptr, fvalue);
   }
+  fflush(stdout);
   return result;
 }
 
@@ -148,10 +185,10 @@ AEffect*VSTPluginMain(AEffectDispatcherProc dispatch4host) {
   if(!plug)
     return plug;
 
-  printf("plugin.dispatcher '%p' -> '%p'\n", plug->dispatcher, host2plugin);
-  if(plug->dispatcher != host2plugin) {
+  printf("plugin.dispatcher '%p' -> '%p'\n", plug->dispatcher, host2plugin_wrapper);
+  if(plug->dispatcher != host2plugin_wrapper) {
     s_host2plugin[plug] = plug->dispatcher;
-    plug->dispatcher = host2plugin;
+    plug->dispatcher = host2plugin_wrapper;
   }
 
   s_host2plugin[plug](plug, effGetEffectName, 0, 0, pluginname, 0);
